@@ -58,15 +58,16 @@ class Stream(object):
         else:
             socket_type = SOCK_DGRAM
         try:
-            date_utc = datetime.utcnow().isoformat("T") + "Z"
+            date_time = datetime.now().strftime("%b %d %H:%M:%S")\
+                                      .lstrip("0").replace(" 0", "  ")
             logger = logging.getLogger(appname)
             logger.handlers = []
             logger.setLevel(logging.INFO)
             syslog = SysLogHandler(address=(host, int(port)),
                                    facility=facility, socktype=socket_type)
             formatter = logging.Formatter('{0} {1} %(name)s:\
-                                           %(message)s'.format(date_utc,
-                                                               self.hostname)),
+                                           %(message)s'.format(date_time,
+                                                               self.hostname))
             syslog.setFormatter(formatter)
             logger.addHandler(syslog)
             for m in messages:
